# DeleteSuccessDto


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**success** | **bool** |  | 

## Example

```python
from montelo.client.models.delete_success_dto import DeleteSuccessDto

# TODO update the JSON string below
json = "{}"
# create an instance of DeleteSuccessDto from a JSON string
delete_success_dto_instance = DeleteSuccessDto.from_json(json)
# print the JSON string representation of the object
print DeleteSuccessDto.to_json()

# convert the object into a dict
delete_success_dto_dict = delete_success_dto_instance.to_dict()
# create an instance of DeleteSuccessDto from a dict
delete_success_dto_form_dict = delete_success_dto.from_dict(delete_success_dto_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


